@@ -59,7 +59,7 @@ class Grapher:
         df = df[0].str.split(',', expand=True)
         temp = df.copy()
         temp[temp.columns] = temp.apply(lambda x: x.str.strip())
-        temp.columns = ['xmin', 'ymin', 'xmax', 'ymax', 'tag']
+        temp.columns = ['xmin', 'ymin', 'xmax', 'ymax', 'Object', 'tag']
         temp[['xmin', 'ymin', 'xmax', 'ymax']] = temp[['xmin', 'ymin', 'xmax', 'ymax']].apply(pd.to_numeric)
         df = temp
 
@@ -70,6 +70,7 @@ class Grapher:
         assert 'ymin' in df.columns, '"ymin" not in object map'
         assert 'ymax' in df.columns, '"ymax" not in object map'
         assert 'Object' in df.columns, '"Object" column not in object map'
+        assert 'tag' in df.columns, '"tag" column not in object map'
 
         # remove empty spaces both in front and behind
         for col in df.columns:
